@@ -12,7 +12,7 @@
 get_header();
 ?>
 
-	<section id="primary" class="content-area">
+	<div id="primary" class="content-area">
 		<main id="main" class="site-main">
 
 			<div class="error-404 not-found">
@@ -27,7 +27,7 @@ get_header();
 			</div><!-- .error-404 -->
 
 		</main><!-- #main -->
-	</section><!-- #primary -->
+	</div><!-- #primary -->
 
 <?php
 get_footer();
