@@ -29,7 +29,6 @@ class WP_Customize_Nav_Menu_Item_Setting extends WP_Customize_Setting {
 	 * Setting type.
 	 *
 	 * @since 4.3.0
-	 * @access public
 	 * @var string
 	 */
 	public $type = self::TYPE;
@@ -38,7 +37,6 @@ class WP_Customize_Nav_Menu_Item_Setting extends WP_Customize_Setting {
 	 * Default setting value.
 	 *
 	 * @since 4.3.0
-	 * @access public
 	 * @var array
 	 *
 	 * @see wp_setup_nav_menu_item()
@@ -68,7 +66,6 @@ class WP_Customize_Nav_Menu_Item_Setting extends WP_Customize_Setting {
 	 *
 	 * @since 4.3.0
 	 * @since 4.5.0 Default changed to 'refresh'
-	 * @access public
 	 * @var string
 	 */
 	public $transport = 'refresh';
@@ -79,7 +76,6 @@ class WP_Customize_Nav_Menu_Item_Setting extends WP_Customize_Setting {
 	 * A negative value represents a placeholder ID for a new menu not yet saved.
 	 *
 	 * @since 4.3.0
-	 * @access public
 	 * @var int
 	 */
 	public $post_id;
@@ -88,8 +84,7 @@ class WP_Customize_Nav_Menu_Item_Setting extends WP_Customize_Setting {
 	 * Storage of pre-setup menu item to prevent wasted calls to wp_setup_nav_menu_item().
 	 *
 	 * @since 4.3.0
-	 * @access protected
-	 * @var array
+	 * @var array|null
 	 */
 	protected $value;
 
@@ -102,7 +97,6 @@ class WP_Customize_Nav_Menu_Item_Setting extends WP_Customize_Setting {
 	 * a real post.
 	 *
 	 * @since 4.3.0
-	 * @access public
 	 * @var int
 	 *
 	 * @see WP_Customize_Nav_Menu_Item_Setting::update()
@@ -115,7 +109,6 @@ class WP_Customize_Nav_Menu_Item_Setting extends WP_Customize_Setting {
 	 * which ensures that we can apply the proper filters.
 	 *
 	 * @since 4.3.0
-	 * @access public
 	 * @var int
 	 */
 	public $original_nav_menu_term_id;
@@ -124,7 +117,6 @@ class WP_Customize_Nav_Menu_Item_Setting extends WP_Customize_Setting {
 	 * Whether or not update() was called.
 	 *
 	 * @since 4.3.0
-	 * @access protected
 	 * @var bool
 	 */
 	protected $is_updated = false;
@@ -138,7 +130,6 @@ class WP_Customize_Nav_Menu_Item_Setting extends WP_Customize_Setting {
 	 * When status is error, the error is stored in $update_error.
 	 *
 	 * @since 4.3.0
-	 * @access public
 	 * @var string updated|inserted|deleted|error
 	 *
 	 * @see WP_Customize_Nav_Menu_Item_Setting::update()
@@ -150,7 +141,6 @@ class WP_Customize_Nav_Menu_Item_Setting extends WP_Customize_Setting {
 	 * Any error object returned by wp_update_nav_menu_item() when setting is updated.
 	 *
 	 * @since 4.3.0
-	 * @access public
 	 * @var WP_Error
 	 *
 	 * @see WP_Customize_Nav_Menu_Item_Setting::update()
@@ -164,7 +154,6 @@ class WP_Customize_Nav_Menu_Item_Setting extends WP_Customize_Setting {
 	 * Any supplied $args override class property defaults.
 	 *
 	 * @since 4.3.0
-	 * @access public
 	 *
 	 * @param WP_Customize_Manager $manager Bootstrap Customizer instance.
 	 * @param string               $id      An specific ID of the setting. Can be a
@@ -201,7 +190,6 @@ class WP_Customize_Nav_Menu_Item_Setting extends WP_Customize_Setting {
 	 * Clear the cached value when this nav menu item is updated.
 	 *
 	 * @since 4.3.0
-	 * @access public
 	 *
 	 * @param int $menu_id       The term ID for the menu.
 	 * @param int $menu_item_id  The post ID for the menu item.
@@ -217,7 +205,6 @@ class WP_Customize_Nav_Menu_Item_Setting extends WP_Customize_Setting {
 	 * Get the instance data for a given nav_menu_item setting.
 	 *
 	 * @since 4.3.0
-	 * @access public
 	 *
 	 * @see wp_setup_nav_menu_item()
 	 *
@@ -246,7 +233,7 @@ class WP_Customize_Nav_Menu_Item_Setting extends WP_Customize_Setting {
 				$post = get_post( $this->post_id );
 				if ( $post && self::POST_TYPE === $post->post_type ) {
 					$is_title_empty = empty( $post->post_title );
-					$value = (array) wp_setup_nav_menu_item( $post );
+					$value          = (array) wp_setup_nav_menu_item( $post );
 					if ( $is_title_empty ) {
 						$value['title'] = '';
 					}
@@ -274,7 +261,6 @@ class WP_Customize_Nav_Menu_Item_Setting extends WP_Customize_Setting {
 	 * Get original title.
 	 *
 	 * @since 4.7.0
-	 * @access protected
 	 *
 	 * @param object $item Nav menu item.
 	 * @return string The original title.
@@ -288,7 +274,7 @@ class WP_Customize_Nav_Menu_Item_Setting extends WP_Customize_Setting {
 				$original_title = apply_filters( 'the_title', $original_object->post_title, $original_object->ID );
 
 				if ( '' === $original_title ) {
-					/* translators: %d: ID of a post */
+					/* translators: %d: ID of a post. */
 					$original_title = sprintf( __( '#%d (no title)' ), $original_object->ID );
 				}
 			}
@@ -311,7 +297,6 @@ class WP_Customize_Nav_Menu_Item_Setting extends WP_Customize_Setting {
 	 * Get type label.
 	 *
 	 * @since 4.7.0
-	 * @access protected
 	 *
 	 * @param object $item Nav menu item.
 	 * @returns string The type label.
@@ -345,7 +330,6 @@ class WP_Customize_Nav_Menu_Item_Setting extends WP_Customize_Setting {
 	 * Translates some properties added by wp_setup_nav_menu_item() and removes others.
 	 *
 	 * @since 4.3.0
-	 * @access protected
 	 *
 	 * @see WP_Customize_Nav_Menu_Item_Setting::value()
 	 */
@@ -368,9 +352,13 @@ class WP_Customize_Nav_Menu_Item_Setting extends WP_Customize_Setting {
 		}
 
 		if ( ! isset( $this->value['nav_menu_term_id'] ) && $this->post_id > 0 ) {
-			$menus = wp_get_post_terms( $this->post_id, WP_Customize_Nav_Menu_Setting::TAXONOMY, array(
-				'fields' => 'ids',
-			) );
+			$menus = wp_get_post_terms(
+				$this->post_id,
+				WP_Customize_Nav_Menu_Setting::TAXONOMY,
+				array(
+					'fields' => 'ids',
+				)
+			);
 			if ( ! empty( $menus ) ) {
 				$this->value['nav_menu_term_id'] = array_shift( $menus );
 			} else {
@@ -395,7 +383,7 @@ class WP_Customize_Nav_Menu_Item_Setting extends WP_Customize_Setting {
 
 		if ( ! isset( $this->value['_invalid'] ) ) {
 			$this->value['_invalid'] = false;
-			$is_known_invalid = (
+			$is_known_invalid        = (
 				( ( 'post_type' === $this->value['type'] || 'post_type_archive' === $this->value['type'] ) && ! post_type_exists( $this->value['object'] ) )
 				||
 				( 'taxonomy' === $this->value['type'] && ! taxonomy_exists( $this->value['object'] ) )
@@ -441,7 +429,6 @@ class WP_Customize_Nav_Menu_Item_Setting extends WP_Customize_Setting {
 	 *
 	 * @since 4.3.0
 	 * @since 4.4.0 Added boolean return value.
-	 * @access public
 	 *
 	 * @see WP_Customize_Manager::post_value()
 	 *
@@ -452,9 +439,9 @@ class WP_Customize_Nav_Menu_Item_Setting extends WP_Customize_Setting {
 			return false;
 		}
 
-		$undefined = new stdClass();
+		$undefined      = new stdClass();
 		$is_placeholder = ( $this->post_id < 0 );
-		$is_dirty = ( $undefined !== $this->post_value( $undefined ) );
+		$is_dirty       = ( $undefined !== $this->post_value( $undefined ) );
 		if ( ! $is_placeholder && ! $is_dirty ) {
 			return false;
 		}
@@ -480,19 +467,21 @@ class WP_Customize_Nav_Menu_Item_Setting extends WP_Customize_Setting {
 	 * Filters the wp_get_nav_menu_items() result to supply the previewed menu items.
 	 *
 	 * @since 4.3.0
-	 * @access public
 	 *
 	 * @see wp_get_nav_menu_items()
 	 *
-	 * @param array  $items An array of menu item post objects.
-	 * @param object $menu  The menu object.
-	 * @param array  $args  An array of arguments used to retrieve menu item objects.
-	 * @return array Array of menu items,
+	 * @param WP_Post[] $items An array of menu item post objects.
+	 * @param WP_Term   $menu  The menu object.
+	 * @param array     $args  An array of arguments used to retrieve menu item objects.
+	 * @return WP_Post[] Array of menu item objects.
 	 */
 	public function filter_wp_get_nav_menu_items( $items, $menu, $args ) {
-		$this_item = $this->value();
-		$current_nav_menu_term_id = $this_item['nav_menu_term_id'];
-		unset( $this_item['nav_menu_term_id'] );
+		$this_item                = $this->value();
+		$current_nav_menu_term_id = null;
+		if ( isset( $this_item['nav_menu_term_id'] ) ) {
+			$current_nav_menu_term_id = $this_item['nav_menu_term_id'];
+			unset( $this_item['nav_menu_term_id'] );
+		}
 
 		$should_filter = (
 			$menu->term_id === $this->original_nav_menu_term_id
@@ -507,7 +496,7 @@ class WP_Customize_Nav_Menu_Item_Setting extends WP_Customize_Setting {
 		$should_remove = (
 			false === $this_item
 			||
-			true === $this_item['_invalid']
+			( isset( $this_item['_invalid'] ) && true === $this_item['_invalid'] )
 			||
 			(
 				$this->original_nav_menu_term_id === $menu->term_id
@@ -525,7 +514,7 @@ class WP_Customize_Nav_Menu_Item_Setting extends WP_Customize_Setting {
 			return $filtered_items;
 		}
 
-		$mutated = false;
+		$mutated       = false;
 		$should_update = (
 			is_array( $this_item )
 			&&
@@ -554,15 +543,13 @@ class WP_Customize_Nav_Menu_Item_Setting extends WP_Customize_Setting {
 	 * Re-apply the tail logic also applied on $items by wp_get_nav_menu_items().
 	 *
 	 * @since 4.3.0
-	 * @access public
-	 * @static
 	 *
 	 * @see wp_get_nav_menu_items()
 	 *
-	 * @param array  $items An array of menu item post objects.
-	 * @param object $menu  The menu object.
-	 * @param array  $args  An array of arguments used to retrieve menu item objects.
-	 * @return array Array of menu items,
+	 * @param WP_Post[] $items An array of menu item post objects.
+	 * @param WP_Term   $menu  The menu object.
+	 * @param array     $args  An array of arguments used to retrieve menu item objects.
+	 * @return WP_Post[] Array of menu item objects.
 	 */
 	public static function sort_wp_get_nav_menu_items( $items, $menu, $args ) {
 		// @todo We should probably re-apply some constraints imposed by $args.
@@ -574,10 +561,13 @@ class WP_Customize_Nav_Menu_Item_Setting extends WP_Customize_Setting {
 		}
 
 		if ( ARRAY_A === $args['output'] ) {
-			$items = wp_list_sort( $items, array(
-				$args['output_key'] => 'ASC',
-			) );
-			$i = 1;
+			$items = wp_list_sort(
+				$items,
+				array(
+					$args['output_key'] => 'ASC',
+				)
+			);
+			$i     = 1;
 
 			foreach ( $items as $k => $item ) {
 				$items[ $k ]->{$args['output_key']} = $i++;
@@ -591,7 +581,6 @@ class WP_Customize_Nav_Menu_Item_Setting extends WP_Customize_Setting {
 	 * Get the value emulated into a WP_Post and set up as a nav_menu_item.
 	 *
 	 * @since 4.3.0
-	 * @access public
 	 *
 	 * @return WP_Post With wp_setup_nav_menu_item() applied.
 	 */
@@ -602,7 +591,7 @@ class WP_Customize_Nav_Menu_Item_Setting extends WP_Customize_Setting {
 		$item->post_status = $item->status;
 		unset( $item->status );
 
-		$item->post_type = 'nav_menu_item';
+		$item->post_type  = 'nav_menu_item';
 		$item->menu_order = $item->position;
 		unset( $item->position );
 
@@ -616,9 +605,9 @@ class WP_Customize_Nav_Menu_Item_Setting extends WP_Customize_Setting {
 			$item->post_title = $item->title;
 		}
 
-		$item->ID = $this->post_id;
+		$item->ID    = $this->post_id;
 		$item->db_id = $this->post_id;
-		$post = new WP_Post( (object) $item );
+		$post        = new WP_Post( (object) $item );
 
 		if ( empty( $post->post_author ) ) {
 			$post->post_author = get_current_user_id();
@@ -659,11 +648,10 @@ class WP_Customize_Nav_Menu_Item_Setting extends WP_Customize_Setting {
 	 * we remove that in this override.
 	 *
 	 * @since 4.3.0
-	 * @access public
 	 *
 	 * @param array $menu_item_value The value to sanitize.
-	 * @return array|false|null Null if an input isn't valid. False if it is marked for deletion.
-	 *                          Otherwise the sanitized value.
+	 * @return array|false|null|WP_Error Null or WP_Error if an input isn't valid. False if it is marked for deletion.
+	 *                                   Otherwise the sanitized value.
 	 */
 	public function sanitize( $menu_item_value ) {
 		// Menu is marked for deletion.
@@ -676,7 +664,7 @@ class WP_Customize_Nav_Menu_Item_Setting extends WP_Customize_Setting {
 			return null;
 		}
 
-		$default = array(
+		$default                     = array(
 			'object_id'        => 0,
 			'object'           => '',
 			'menu_item_parent' => 0,
@@ -694,8 +682,8 @@ class WP_Customize_Nav_Menu_Item_Setting extends WP_Customize_Setting {
 			'nav_menu_term_id' => 0,
 			'_invalid'         => false,
 		);
-		$menu_item_value = array_merge( $default, $menu_item_value );
-		$menu_item_value = wp_array_slice_assoc( $menu_item_value, array_keys( $default ) );
+		$menu_item_value             = array_merge( $default, $menu_item_value );
+		$menu_item_value             = wp_array_slice_assoc( $menu_item_value, array_keys( $default ) );
 		$menu_item_value['position'] = intval( $menu_item_value['position'] );
 
 		foreach ( array( 'object_id', 'menu_item_parent', 'nav_menu_term_id' ) as $key ) {
@@ -718,11 +706,22 @@ class WP_Customize_Nav_Menu_Item_Setting extends WP_Customize_Setting {
 		$menu_item_value['original_title'] = sanitize_text_field( $menu_item_value['original_title'] );
 
 		// Apply the same filters as when calling wp_insert_post().
+
+		/** This filter is documented in wp-includes/post.php */
 		$menu_item_value['title'] = wp_unslash( apply_filters( 'title_save_pre', wp_slash( $menu_item_value['title'] ) ) );
+
+		/** This filter is documented in wp-includes/post.php */
 		$menu_item_value['attr_title'] = wp_unslash( apply_filters( 'excerpt_save_pre', wp_slash( $menu_item_value['attr_title'] ) ) );
+
+		/** This filter is documented in wp-includes/post.php */
 		$menu_item_value['description'] = wp_unslash( apply_filters( 'content_save_pre', wp_slash( $menu_item_value['description'] ) ) );
 
-		$menu_item_value['url'] = esc_url_raw( $menu_item_value['url'] );
+		if ( '' !== $menu_item_value['url'] ) {
+			$menu_item_value['url'] = esc_url_raw( $menu_item_value['url'] );
+			if ( '' === $menu_item_value['url'] ) {
+				return new WP_Error( 'invalid_url', __( 'Invalid URL.' ) ); // Fail sanitization if URL is invalid.
+			}
+		}
 		if ( 'publish' !== $menu_item_value['status'] ) {
 			$menu_item_value['status'] = 'draft';
 		}
@@ -743,7 +742,6 @@ class WP_Customize_Nav_Menu_Item_Setting extends WP_Customize_Setting {
 	 * To delete a menu, the client can send false as the value.
 	 *
 	 * @since 4.3.0
-	 * @access protected
 	 *
 	 * @see wp_update_nav_menu_item()
 	 *
@@ -860,12 +858,12 @@ class WP_Customize_Nav_Menu_Item_Setting extends WP_Customize_Setting {
 
 			if ( is_wp_error( $r ) ) {
 				$this->update_status = 'error';
-				$this->update_error = $r;
+				$this->update_error  = $r;
 			} else {
 				if ( $is_placeholder ) {
 					$this->previous_post_id = $this->post_id;
-					$this->post_id = $r;
-					$this->update_status = 'inserted';
+					$this->post_id          = $r;
+					$this->update_status    = 'inserted';
 				} else {
 					$this->update_status = 'updated';
 				}
@@ -878,7 +876,6 @@ class WP_Customize_Nav_Menu_Item_Setting extends WP_Customize_Setting {
 	 * Export data for the JS client.
 	 *
 	 * @since 4.3.0
-	 * @access public
 	 *
 	 * @see WP_Customize_Nav_Menu_Item_Setting::update()
 	 *
