@@ -58,7 +58,6 @@ class WP_REST_Server {
 	 * Namespaces registered to the server.
 	 *
 	 * @since 4.4.0
-	 * @access protected
 	 * @var array
 	 */
 	protected $namespaces = array();
@@ -67,7 +66,6 @@ class WP_REST_Server {
 	 * Endpoints registered to the server.
 	 *
 	 * @since 4.4.0
-	 * @access protected
 	 * @var array
 	 */
 	protected $endpoints = array();
@@ -76,7 +74,6 @@ class WP_REST_Server {
 	 * Options defined for the routes.
 	 *
 	 * @since 4.4.0
-	 * @access protected
 	 * @var array
 	 */
 	protected $route_options = array();
@@ -85,15 +82,14 @@ class WP_REST_Server {
 	 * Instantiates the REST server.
 	 *
 	 * @since 4.4.0
-	 * @access public
 	 */
 	public function __construct() {
 		$this->endpoints = array(
 			// Meta endpoints.
 			'/' => array(
 				'callback' => array( $this, 'get_index' ),
-				'methods' => 'GET',
-				'args' => array(
+				'methods'  => 'GET',
+				'args'     => array(
 					'context' => array(
 						'default' => 'view',
 					),
@@ -107,7 +103,6 @@ class WP_REST_Server {
 	 * Checks the authentication headers if supplied.
 	 *
 	 * @since 4.4.0
-	 * @access public
 	 *
 	 * @return WP_Error|null WP_Error indicates unsuccessful login, null indicates successful
 	 *                       or no authentication provided
@@ -148,7 +143,6 @@ class WP_REST_Server {
 	 * list in JSON rather than an object/map.
 	 *
 	 * @since 4.4.0
-	 * @access protected
 	 *
 	 * @param WP_Error $error WP_Error instance.
 	 * @return WP_REST_Response List of associative arrays with code and message keys.
@@ -166,7 +160,11 @@ class WP_REST_Server {
 
 		foreach ( (array) $error->errors as $code => $messages ) {
 			foreach ( (array) $messages as $message ) {
-				$errors[] = array( 'code' => $code, 'message' => $message, 'data' => $error->get_error_data( $code ) );
+				$errors[] = array(
+					'code'    => $code,
+					'message' => $message,
+					'data'    => $error->get_error_data( $code ),
+				);
 			}
 		}
 
@@ -191,7 +189,6 @@ class WP_REST_Server {
 	 * a 'status' key, with the value being the HTTP status to send.
 	 *
 	 * @since 4.4.0
-	 * @access protected
 	 *
 	 * @param string $code    WP_Error-style code.
 	 * @param string $message Human-readable message.
@@ -215,7 +212,6 @@ class WP_REST_Server {
 	 * callback then outputs a JSON representation of the returned value.
 	 *
 	 * @since 4.4.0
-	 * @access public
 	 *
 	 * @see WP_REST_Server::dispatch()
 	 *
@@ -268,7 +264,11 @@ class WP_REST_Server {
 		 *
 		 * @param bool $rest_enabled Whether the REST API is enabled. Default true.
 		 */
-		apply_filters_deprecated( 'rest_enabled', array( true ), '4.7.0', 'rest_authentication_errors',
+		apply_filters_deprecated(
+			'rest_enabled',
+			array( true ),
+			'4.7.0',
+			'rest_authentication_errors',
 			__( 'The REST API can no longer be completely disabled, the rest_authentication_errors filter can be used to restrict access to the API, instead.' )
 		);
 
@@ -310,7 +310,7 @@ class WP_REST_Server {
 		$request->set_body_params( wp_unslash( $_POST ) );
 		$request->set_file_params( $_FILES );
 		$request->set_headers( $this->get_headers( wp_unslash( $_SERVER ) ) );
-		$request->set_body( $this->get_raw_data() );
+		$request->set_body( self::get_raw_data() );
 
 		/*
 		 * HTTP method override for clients that can't use PUT/PATCH/DELETE. First, we check
@@ -387,13 +387,32 @@ class WP_REST_Server {
 			// Embed links inside the request.
 			$result = $this->response_to_data( $result, isset( $_GET['_embed'] ) );
 
+			/**
+			 * Filters the API response.
+			 *
+			 * Allows modification of the response data after inserting
+			 * embedded data (if any) and before echoing the response data.
+			 *
+			 * @since 4.8.1
+			 *
+			 * @param array            $result  Response data to send to the client.
+			 * @param WP_REST_Server   $this    Server instance.
+			 * @param WP_REST_Request  $request Request used to generate the response.
+			 */
+			$result = apply_filters( 'rest_pre_echo_response', $result, $this, $request );
+
+			// The 204 response shouldn't have a body.
+			if ( 204 === $code || null === $result ) {
+				return null;
+			}
+
 			$result = wp_json_encode( $result );
 
 			$json_error_message = $this->get_json_last_error();
 			if ( $json_error_message ) {
 				$json_error_obj = new WP_Error( 'rest_encode_error', $json_error_message, array( 'status' => 500 ) );
-				$result = $this->error_to_response( $json_error_obj );
-				$result = wp_json_encode( $result->data[0] );
+				$result         = $this->error_to_response( $json_error_obj );
+				$result         = wp_json_encode( $result->data[0] );
 			}
 
 			if ( $jsonp_callback ) {
@@ -411,7 +430,6 @@ class WP_REST_Server {
 	 * Converts a response to data to send.
 	 *
 	 * @since 4.4.0
-	 * @access public
 	 *
 	 * @param WP_REST_Response $response Response object.
 	 * @param bool             $embed    Whether links should be embedded.
@@ -424,7 +442,7 @@ class WP_REST_Server {
 	 */
 	public function response_to_data( $response, $embed ) {
 		$data  = $response->get_data();
-		$links = $this->get_compact_response_links( $response );
+		$links = self::get_compact_response_links( $response );
 
 		if ( ! empty( $links ) ) {
 			// Convert links to part of the data.
@@ -449,8 +467,6 @@ class WP_REST_Server {
 	 * direct output.
 	 *
 	 * @since 4.4.0
-	 * @access public
-	 * @static
 	 *
 	 * @param WP_REST_Response $response Response to extract links from.
 	 * @return array Map of link relation to list of link hashes.
@@ -467,9 +483,9 @@ class WP_REST_Server {
 			$data[ $rel ] = array();
 
 			foreach ( $items as $item ) {
-				$attributes = $item['attributes'];
+				$attributes         = $item['attributes'];
 				$attributes['href'] = $item['href'];
-				$data[ $rel ][] = $attributes;
+				$data[ $rel ][]     = $attributes;
 			}
 		}
 
@@ -483,8 +499,6 @@ class WP_REST_Server {
 	 * direct output.
 	 *
 	 * @since 4.5.0
-	 * @access public
-	 * @static
 	 *
 	 * @param WP_REST_Response $response Response to extract links from.
 	 * @return array Map of link relation to list of link hashes.
@@ -496,7 +510,7 @@ class WP_REST_Server {
 			return array();
 		}
 
-		$curies = $response->get_curies();
+		$curies      = $response->get_curies();
 		$used_curies = array();
 
 		foreach ( $links as $rel => $items ) {
@@ -512,9 +526,9 @@ class WP_REST_Server {
 				$rel_regex = str_replace( '\{rel\}', '(.+)', preg_quote( $curie['href'], '!' ) );
 				preg_match( '!' . $rel_regex . '!', $rel, $matches );
 				if ( $matches ) {
-					$new_rel = $curie['name'] . ':' . $matches[1];
+					$new_rel                       = $curie['name'] . ':' . $matches[1];
 					$used_curies[ $curie['name'] ] = $curie;
-					$links[ $new_rel ] = $items;
+					$links[ $new_rel ]             = $items;
 					unset( $links[ $rel ] );
 					break;
 				}
@@ -533,7 +547,6 @@ class WP_REST_Server {
 	 * Embeds the links from the data into the request.
 	 *
 	 * @since 4.4.0
-	 * @access protected
 	 *
 	 * @param array $data Data from the request.
 	 * @return array {
@@ -551,11 +564,6 @@ class WP_REST_Server {
 		$embedded = array();
 
 		foreach ( $data['_links'] as $rel => $links ) {
-			// Ignore links to self, for obvious reasons.
-			if ( 'self' === $rel ) {
-				continue;
-			}
-
 			$embeds = array();
 
 			foreach ( $links as $item ) {
@@ -609,7 +617,6 @@ class WP_REST_Server {
 	 * data instead.
 	 *
 	 * @since 4.4.0
-	 * @access public
 	 *
 	 * @param WP_REST_Response $response Response object.
 	 * @param bool             $embed    Whether links should be embedded.
@@ -640,7 +647,6 @@ class WP_REST_Server {
 	 * Registers a route to the server.
 	 *
 	 * @since 4.4.0
-	 * @access public
 	 *
 	 * @param string $namespace  Namespace.
 	 * @param string $route      The REST route.
@@ -652,25 +658,29 @@ class WP_REST_Server {
 		if ( ! isset( $this->namespaces[ $namespace ] ) ) {
 			$this->namespaces[ $namespace ] = array();
 
-			$this->register_route( $namespace, '/' . $namespace, array(
+			$this->register_route(
+				$namespace,
+				'/' . $namespace,
 				array(
-					'methods' => self::READABLE,
-					'callback' => array( $this, 'get_namespace_index' ),
-					'args' => array(
-						'namespace' => array(
-							'default' => $namespace,
-						),
-						'context' => array(
-							'default' => 'view',
+					array(
+						'methods'  => self::READABLE,
+						'callback' => array( $this, 'get_namespace_index' ),
+						'args'     => array(
+							'namespace' => array(
+								'default' => $namespace,
+							),
+							'context'   => array(
+								'default' => 'view',
+							),
 						),
 					),
-				),
-			) );
+				)
+			);
 		}
 
 		// Associative to avoid double-registration.
 		$this->namespaces[ $namespace ][ $route ] = true;
-		$route_args['namespace'] = $namespace;
+		$route_args['namespace']                  = $namespace;
 
 		if ( $override || empty( $this->endpoints[ $route ] ) ) {
 			$this->endpoints[ $route ] = $route_args;
@@ -695,7 +705,6 @@ class WP_REST_Server {
 	 * used as the delimiter with preg_match()
 	 *
 	 * @since 4.4.0
-	 * @access public
 	 *
 	 * @return array `'/path/regex' => array( $callback, $bitmask )` or
 	 *               `'/path/regex' => array( array( $callback, $bitmask ), ...)`.
@@ -757,7 +766,7 @@ class WP_REST_Server {
 				$handler['methods'] = array();
 
 				foreach ( $methods as $method ) {
-					$method = strtoupper( trim( $method ) );
+					$method                        = strtoupper( trim( $method ) );
 					$handler['methods'][ $method ] = true;
 				}
 			}
@@ -770,7 +779,6 @@ class WP_REST_Server {
 	 * Retrieves namespaces registered on the server.
 	 *
 	 * @since 4.4.0
-	 * @access public
 	 *
 	 * @return array List of registered namespaces.
 	 */
@@ -782,7 +790,6 @@ class WP_REST_Server {
 	 * Retrieves specified options for a route.
 	 *
 	 * @since 4.4.0
-	 * @access public
 	 *
 	 * @param string $route Route pattern to fetch options for.
 	 * @return array|null Data as an associative array if found, or null if not found.
@@ -799,7 +806,6 @@ class WP_REST_Server {
 	 * Matches the request to a callback and call it.
 	 *
 	 * @since 4.4.0
-	 * @access public
 	 *
 	 * @param WP_REST_Request $request Request to attempt dispatching.
 	 * @return WP_REST_Response Response returned by the callback.
@@ -828,14 +834,21 @@ class WP_REST_Server {
 		$path   = $request->get_route();
 
 		foreach ( $this->get_routes() as $route => $handlers ) {
-			$match = preg_match( '@^' . $route . '$@i', $path, $args );
+			$match = preg_match( '@^' . $route . '$@i', $path, $matches );
 
 			if ( ! $match ) {
 				continue;
 			}
 
+			$args = array();
+			foreach ( $matches as $param => $value ) {
+				if ( ! is_int( $param ) ) {
+					$args[ $param ] = $value;
+				}
+			}
+
 			foreach ( $handlers as $handler ) {
-				$callback  = $handler['callback'];
+				$callback = $handler['callback'];
 				$response = null;
 
 				// Fallback to GET method if no HEAD method is registered.
@@ -891,9 +904,9 @@ class WP_REST_Server {
 				 *
 				 * @since 4.7.0
 				 *
-				 * @param WP_HTTP_Response $response Result to send to the client. Usually a WP_REST_Response.
-				 * @param WP_REST_Server   $handler  ResponseHandler instance (usually WP_REST_Server).
-				 * @param WP_REST_Request  $request  Request used to generate the response.
+				 * @param WP_HTTP_Response|WP_Error $response Result to send to the client. Usually a WP_REST_Response or WP_Error.
+				 * @param array                     $handler  Route handler used for the request.
+				 * @param WP_REST_Request           $request  Request used to generate the response.
 				 */
 				$response = apply_filters( 'rest_request_before_callbacks', $response, $handler, $request );
 
@@ -905,7 +918,7 @@ class WP_REST_Server {
 						if ( is_wp_error( $permission ) ) {
 							$response = $permission;
 						} elseif ( false === $permission || null === $permission ) {
-							$response = new WP_Error( 'rest_forbidden', __( 'Sorry, you are not allowed to do that.' ), array( 'status' => 403 ) );
+							$response = new WP_Error( 'rest_forbidden', __( 'Sorry, you are not allowed to do that.' ), array( 'status' => rest_authorization_required_code() ) );
 						}
 					}
 				}
@@ -919,7 +932,7 @@ class WP_REST_Server {
 					 * @since 4.4.0
 					 * @since 4.5.0 Added `$route` and `$handler` parameters.
 					 *
-					 * @param bool            $dispatch_result Dispatch result, will be used if not empty.
+					 * @param mixed           $dispatch_result Dispatch result, will be used if not empty.
 					 * @param WP_REST_Request $request         Request used to generate the response.
 					 * @param string          $route           Route matched for the request.
 					 * @param array           $handler         Route handler used for the request.
@@ -950,9 +963,9 @@ class WP_REST_Server {
 				 *
 				 * @since 4.7.0
 				 *
-				 * @param WP_HTTP_Response $response Result to send to the client. Usually a WP_REST_Response.
-				 * @param WP_REST_Server   $handler  ResponseHandler instance (usually WP_REST_Server).
-				 * @param WP_REST_Request  $request  Request used to generate the response.
+				 * @param WP_HTTP_Response|WP_Error $response Result to send to the client. Usually a WP_REST_Response or WP_Error.
+				 * @param array                     $handler  Route handler used for the request.
+				 * @param WP_REST_Request           $request  Request used to generate the response.
 				 */
 				$response = apply_filters( 'rest_request_after_callbacks', $response, $handler, $request );
 
@@ -979,19 +992,13 @@ class WP_REST_Server {
 	 * "Encoding error: Maximum stack depth exceeded".
 	 *
 	 * @since 4.4.0
-	 * @access protected
 	 *
 	 * @return bool|string Boolean false or string error message.
 	 */
 	protected function get_json_last_error() {
-		// See https://core.trac.wordpress.org/ticket/27799.
-		if ( ! function_exists( 'json_last_error' ) ) {
-			return false;
-		}
-
 		$last_error_code = json_last_error();
 
-		if ( ( defined( 'JSON_ERROR_NONE' ) && JSON_ERROR_NONE === $last_error_code ) || empty( $last_error_code ) ) {
+		if ( JSON_ERROR_NONE === $last_error_code || empty( $last_error_code ) ) {
 			return false;
 		}
 
@@ -1004,7 +1011,6 @@ class WP_REST_Server {
 	 * This endpoint describes the capabilities of the site.
 	 *
 	 * @since 4.4.0
-	 * @access public
 	 *
 	 * @param array $request {
 	 *     Request.
@@ -1049,7 +1055,6 @@ class WP_REST_Server {
 	 * Retrieves the index for a namespace.
 	 *
 	 * @since 4.4.0
-	 * @access public
 	 *
 	 * @param WP_REST_Request $request REST request instance.
 	 * @return WP_REST_Response|WP_Error WP_REST_Response instance if the index was found,
@@ -1062,12 +1067,12 @@ class WP_REST_Server {
 			return new WP_Error( 'rest_invalid_namespace', __( 'The specified namespace could not be found.' ), array( 'status' => 404 ) );
 		}
 
-		$routes = $this->namespaces[ $namespace ];
+		$routes    = $this->namespaces[ $namespace ];
 		$endpoints = array_intersect_key( $this->get_routes(), $routes );
 
-		$data = array(
+		$data     = array(
 			'namespace' => $namespace,
-			'routes' => $this->get_data_for_routes( $endpoints, $request['context'] ),
+			'routes'    => $this->get_data_for_routes( $endpoints, $request['context'] ),
 		);
 		$response = rest_ensure_response( $data );
 
@@ -1092,7 +1097,6 @@ class WP_REST_Server {
 	 * Retrieves the publicly-visible data for routes.
 	 *
 	 * @since 4.4.0
-	 * @access public
 	 *
 	 * @param array  $routes  Routes to get data for.
 	 * @param string $context Optional. Context for data. Accepts 'view' or 'help'. Default 'view'.
@@ -1137,7 +1141,6 @@ class WP_REST_Server {
 	 * Retrieves publicly-visible data for the route.
 	 *
 	 * @since 4.4.0
-	 * @access public
 	 *
 	 * @param string $route     Route to get data for.
 	 * @param array  $callbacks Callbacks to convert to data.
@@ -1147,7 +1150,7 @@ class WP_REST_Server {
 	public function get_data_for_route( $route, $callbacks, $context = 'view' ) {
 		$data = array(
 			'namespace' => '',
-			'methods' => array(),
+			'methods'   => array(),
 			'endpoints' => array(),
 		);
 
@@ -1172,7 +1175,7 @@ class WP_REST_Server {
 			}
 
 			$data['methods'] = array_merge( $data['methods'], array_keys( $callback['methods'] ) );
-			$endpoint_data = array(
+			$endpoint_data   = array(
 				'methods' => array_keys( $callback['methods'] ),
 			);
 
@@ -1223,7 +1226,6 @@ class WP_REST_Server {
 	 * Sends an HTTP status code.
 	 *
 	 * @since 4.4.0
-	 * @access protected
 	 *
 	 * @param int $code HTTP status.
 	 */
@@ -1235,7 +1237,6 @@ class WP_REST_Server {
 	 * Sends an HTTP header.
 	 *
 	 * @since 4.4.0
-	 * @access public
 	 *
 	 * @param string $key Header key.
 	 * @param string $value Header value.
@@ -1256,7 +1257,6 @@ class WP_REST_Server {
 	 * Sends multiple HTTP headers.
 	 *
 	 * @since 4.4.0
-	 * @access public
 	 *
 	 * @param array $headers Map of header name to header value.
 	 */
@@ -1270,31 +1270,17 @@ class WP_REST_Server {
 	 * Removes an HTTP header from the current response.
 	 *
 	 * @since 4.8.0
-	 * @access public
 	 *
 	 * @param string $key Header key.
 	 */
 	public function remove_header( $key ) {
-		if ( function_exists( 'header_remove' ) ) {
-			// In PHP 5.3+ there is a way to remove an already set header.
-			header_remove( $key );
-		} else {
-			// In PHP 5.2, send an empty header, but only as a last resort to
-			// override a header already sent.
-			foreach ( headers_list() as $header ) {
-				if ( 0 === stripos( $header, "$key:" ) ) {
-					$this->send_header( $key, '' );
-					break;
-				}
-			}
-		}
+		header_remove( $key );
 	}
 
 	/**
 	 * Retrieves the raw request entity (body).
 	 *
 	 * @since 4.4.0
-	 * @access public
 	 *
 	 * @global string $HTTP_RAW_POST_DATA Raw post data.
 	 *
@@ -1318,7 +1304,6 @@ class WP_REST_Server {
 	 * Extracts headers from a PHP-style $_SERVER array.
 	 *
 	 * @since 4.4.0
-	 * @access public
 	 *
 	 * @param array $server Associative array similar to `$_SERVER`.
 	 * @return array Headers extracted from the input.
@@ -1327,7 +1312,11 @@ class WP_REST_Server {
 		$headers = array();
 
 		// CONTENT_* headers are not prefixed with HTTP_.
-		$additional = array( 'CONTENT_LENGTH' => true, 'CONTENT_MD5' => true, 'CONTENT_TYPE' => true );
+		$additional = array(
+			'CONTENT_LENGTH' => true,
+			'CONTENT_MD5'    => true,
+			'CONTENT_TYPE'   => true,
+		);
 
 		foreach ( $server as $key => $value ) {
 			if ( strpos( $key, 'HTTP_' ) === 0 ) {
